Skip to contents

Checks for Metadata in a TileDB Group

Usage

tiledb_group_has_metadata(grp, key)

Arguments

grp

A TileDB Group object as for example returned by tiledb_group()

key

A character value with they index under which the data will be written

Value

A logical value indicating if the given key exists in the metadata of the given group